changeset 12359:c83669fb7601 v8.0.1059

patch 8.0.1059: older Gnome terminal returns smaller version number commit https://github.com/vim/vim/commit/3d8d2c7ca5dda5bfd62c6d5df6659cf62e960a3d Author: Bram Moolenaar <Bram@vim.org> Date: Tue Sep 5 21:57:27 2017 +0200 patch 8.0.1059: older Gnome terminal returns smaller version number Problem: older Gnome terminal returns smaller version number. (antarestrue) Solution: Lower version limit from 2800 to 2500. (https://github.com/vim/vim/issues/2032)
author Christian Brabandt <cb@256bit.org>
date Tue, 05 Sep 2017 22:00:05 +0200
parents 529cb40c9c0a
children 588b8fd2c045
files src/term.c src/version.c
diffstat 2 files changed, 5 insertions(+), 3 deletions(-) [+]
line wrap: on
line diff
--- a/src/version.c
+++ b/src/version.c
@@ -770,6 +770,8 @@ static char *(features[]) =
 static int included_patches[] =
 {   /* Add new patch number below this line */
 /**/
+    1059,
+/**/
     1058,
 /**/
     1057,
--- a/src/term.c
+++ b/src/term.c
@@ -4572,12 +4572,12 @@ check_termcode(
 				&& STRNCMP(tp + extra - 2, "1;95;0c", 7) == 0)
 			    is_not_xterm = TRUE;
 #  endif
-			/* Gnome terminal sends 1;3801;0 or 1;4402;0.
+			/* Gnome terminal sends 1;3801;0, 1;4402;0 or 1;2501;0.
 			 * xfce4-terminal sends 1;2802;0.
 			 * screen sends 83;40500;0
 			 * Assuming any version number over 2800 is not an
 			 * xterm (without the limit for rxvt and screen). */
-			if (col >= 2800)
+			if (col >= 2500)
 			    is_not_xterm = TRUE;
 
 			/* PuTTY sends 0;136;0 */
@@ -4572,12 +4572,12 @@ check_termcode(
 			 * xfce4-terminal sends 1;2802;0.
 			 * screen sends 83;40500;0
-			 * Assuming any version number over 2800 is not an
+			 * Assuming any version number over 2500 is not an
 			 * xterm (without the limit for rxvt and screen). */